@@ -1,5 +1,7 @@
 //! The Proposal Header.
 
+use crate::nonce::Nonce;
+
 /// The Proposal Target System.
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
 #[cfg_attr(
@@ -13,14 +15,6 @@ pub enum TargetSystem {
     TreeId(u32),
 }
 
-/// Proposal Nonce (4 bytes).
-#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, Ord, PartialOrd)]
-#[cfg_attr(
-    feature = "scale",
-    derive(scale_info::TypeInfo, scale_codec::Encode, scale_codec::Decode)
-)]
-pub struct Nonce(u32);
-
 /// Proposal Target Function Signature (4 bytes).
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, Ord, PartialOrd)]
 #[cfg_attr(
